==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/DataSource.java <==
package com.example.model;

/**
 * Model for DataSource
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "DataSource", description = "Model for DataSource")
@javax.xml.bind.annotation.XmlRootElement(name = "DataSource")
public class DataSource implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String name = null;
	private java.lang.String result = null;
	private java.lang.String score = null;
	private java.lang.String threshold = null;
	private java.lang.String weight = null;
	
	/**
	 */
	public DataSource name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	@javax.validation.constraints.NotNull
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public DataSource result(java.lang.String result) {
		setResult(result);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("result")
	public java.lang.String getResult() {
		return this.result;
	}
	public void setResult(java.lang.String result) {
		this.result = result;
	}
	
	/**
	 */
	public DataSource score(java.lang.String score) {
		setScore(score);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("score")
	public java.lang.String getScore() {
		return this.score;
	}
	public void setScore(java.lang.String score) {
		this.score = score;
	}
	
	/**
	 */
	public DataSource threshold(java.lang.String threshold) {
		setThreshold(threshold);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("threshold")
	public java.lang.String getThreshold() {
		return this.threshold;
	}
	public void setThreshold(java.lang.String threshold) {
		this.threshold = threshold;
	}
	
	/**
	 */
	public DataSource weight(java.lang.String weight) {
		setWeight(weight);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("weight")
	public java.lang.String getWeight() {
		return this.weight;
	}
	public void setWeight(java.lang.String weight) {
		this.weight = weight;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		DataSource dataSource = (DataSource) o;
		return java.util.Objects.equals(this.name, dataSource.name)
				&& java.util.Objects.equals(this.result, dataSource.result)
				&& java.util.Objects.equals(this.score, dataSource.score)
				&& java.util.Objects.equals(this.threshold, dataSource.threshold)
				&& java.util.Objects.equals(this.weight, dataSource.weight);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.name, this.result, this.score, this.threshold, this.weight);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class DataSource {\n");
		
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    result: ").append(toIndentedString(this.result)).append("\n");
		sb.append("    score: ").append(toIndentedString(this.score)).append("\n");
		sb.append("    threshold: ").append(toIndentedString(this.threshold)).append("\n");
		sb.append("    weight: ").append(toIndentedString(this.weight)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/DataSource.java <==
package com.example.model;

/**
 * Model for DataSource
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "DataSource", description = "Model for DataSource")
@javax.xml.bind.annotation.XmlRootElement(name = "DataSource")
public class DataSource implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String name = null;
	private java.lang.String result = null;
	private java.lang.String score = null;
	private java.lang.String threshold = null;
	private java.lang.String weight = null;
	
	/**
	 */
	public DataSource name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "name")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	@javax.validation.constraints.NotNull
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public DataSource result(java.lang.String result) {
		setResult(result);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "result")
	@com.fasterxml.jackson.annotation.JsonProperty("result")
	public java.lang.String getResult() {
		return this.result;
	}
	public void setResult(java.lang.String result) {
		this.result = result;
	}
	
	/**
	 */
	public DataSource score(java.lang.String score) {
		setScore(score);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "score")
	@com.fasterxml.jackson.annotation.JsonProperty("score")
	public java.lang.String getScore() {
		return this.score;
	}
	public void setScore(java.lang.String score) {
		this.score = score;
	}
	
	/**
	 */
	public DataSource threshold(java.lang.String threshold) {
		setThreshold(threshold);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "threshold")
	@com.fasterxml.jackson.annotation.JsonProperty("threshold")
	public java.lang.String getThreshold() {
		return this.threshold;
	}
	public void setThreshold(java.lang.String threshold) {
		this.threshold = threshold;
	}
	
	/**
	 */
	public DataSource weight(java.lang.String weight) {
		setWeight(weight);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "weight")
	@com.fasterxml.jackson.annotation.JsonProperty("weight")
	public java.lang.String getWeight() {
		return this.weight;
	}
	public void setWeight(java.lang.String weight) {
		this.weight = weight;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		DataSource dataSource = (DataSource) o;
		return java.util.Objects.equals(this.name, dataSource.name)
				&& java.util.Objects.equals(this.result, dataSource.result)
				&& java.util.Objects.equals(this.score, dataSource.score)
				&& java.util.Objects.equals(this.threshold, dataSource.threshold)
				&& java.util.Objects.equals(this.weight, dataSource.weight);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.name, this.result, this.score, this.threshold, this.weight);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class DataSource {\n");
		
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    result: ").append(toIndentedString(this.result)).append("\n");
		sb.append("    score: ").append(toIndentedString(this.score)).append("\n");
		sb.append("    threshold: ").append(toIndentedString(this.threshold)).append("\n");
		sb.append("    weight: ").append(toIndentedString(this.weight)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
